@@ -1,4 +1,4 @@
-ebic.fbed.glm <- function(y, x, gam = NULL, wei = NULL, K = 0, type = "logistic") { 
+ebic.fbed.glm <- function(y, x, univ = NULL, gam = NULL, wei = NULL, K = 0, type = "logistic") { 
   if (type == "logistic") {
     oiko <- binomial(logit)
   } else if (type == "binomial") {  
@@ -22,18 +22,26 @@ ebic.fbed.glm <- function(y, x, gam = NULL, wei = NULL, K = 0, type = "logistic"
   
   if ( is.null(gam) ) {
     con <- 2 - log(p) / log(n)
-    if ( (con) < 0 )  con <- 0
-  } else con <- 2 * gam
+  } else  con <- 2 * gam
+  if ( con < 0 )  con <- 0
   lik1 <- BIC( glm(y ~ 1, family = oiko, weights = wei) ) 
   
   runtime <- proc.time()
   
-  for ( i in ind ) {
-    fit2 <- glm( y ~ x[, i], family = oiko, weights = wei, model = FALSE ) 
-    lik2[i] <- BIC(fit2) + con * log(p)
-  }
-  n.tests <- p
-  stat <- lik1 - lik2
+  if ( is.null(univ) ) {
+    for ( i in ind ) {
+      fit2 <- glm( y ~ x[, i], family = oiko, weights = wei, model = FALSE ) 
+      lik2[i] <- BIC(fit2) + con * log(p)
+    }
+    n.tests <- p
+    stat <- lik1 - lik2
+    univ <- list()
+    univ$ebic <- lik2
+  } else {  
+    n.tests <- 0
+    lik2 <- univ$ebic
+    stat <- lik1 - lik2
+  } 
   s <- which(stat > 0)
   
   if ( length(s) > 0 ) {
@@ -195,8 +203,8 @@ ebic.fbed.glm <- function(y, x, gam = NULL, wei = NULL, K = 0, type = "logistic"
     info <- matrix(c(0, p), ncol = 2)
   }
 
-  colnames(res) <- c("Vars", "eBIC")
+  colnames(res) <- c("Vars", "eBIC difference")
   rownames(info) <- paste("K=", 1:length(card)- 1, sep = "")
   colnames(info) <- c("Number of vars", "Number of tests")
-  list(res = res, info = info, runtime = runtime)
+  list(univ = univ, res = res, info = info, runtime = runtime)
 }
