@@ -4,7 +4,11 @@ ebic.fbed.glmm <- function(y, x, id, univ = NULL, gam = NULL, wei = NULL, K = 0,
     oiko <- binomial(logit)
   } else if (test == "testIndGLMMPois") {  
     oiko <- poisson(log)
-  } 
+  } else if (test == "testIndGLMMGamma") {  
+    oiko <- Gamma(log)
+  } else if (test == "testIndGLMMNormLog") {  
+    oiko <- gaussian(log)
+  }
   
   dm <- dim(x)
   n <- dm[1]
