@@ -1,4 +1,4 @@
-glmm.ci.mm <- function(ind1, ind2, cs = NULL, dat, id) {
+glmm.ci.mm <- function(ind1, ind2, cs = NULL, dat, group) {
   
   y <- dat[, ind1]
   x <- dat[, ind2]
@@ -7,88 +7,100 @@ glmm.ci.mm <- function(ind1, ind2, cs = NULL, dat, id) {
   if ( is.null(cs) ) {
     dof <- 1
     if ( Rfast::sort_unique.length(y) == 2 ) {
-      mod1 <- lme4::glmer(y ~ x + (1|id), family = "binomial")
-      mod0 <- lme4::glmer(y ~ 1 + (1|id), family = "binomial")
+      mod1 <- lme4::glmer(y ~ x + (1|group), family = "binomial")
+      mod0 <- lme4::glmer(y ~ 1 + (1|group), family = "binomial")
       t1 <- anova(mod0, mod1)[2, 6]
       p1 <- pchisq(t1, 1, lower.tail = FALSE, log.p = TRUE)
     } else if ( sum(round(y) - y) == 0 ) {
-      mod1 <- lme4::glmer(y ~ x + (1|id), family = "poisson")
-      mod0 <- lme4::glmer(y ~ 1 + (1|id), family = "poisson")
+      mod1 <- lme4::glmer(y ~ x + (1|group), family = "poisson")
+      mod0 <- lme4::glmer(y ~ 1 + (1|group), family = "poisson")
       t1 <- anova(mod0, mod1)[2, 6]
       p1 <- pchisq(t1, 1, lower.tail = FALSE, log.p = TRUE)
     } else {
       dof <- n - 4
-      mod1 <- Rfast::rint.reg(y, x, id)
-      t1 <- ( mod1$be[2, ]/mod1$seb[2, ] )^2
-      p1 <- pf(t1, 1, dof, lower.tail = FALSE, log.p = TRUE)
+      mod1 <- Rfast::rint.reg(y, x, group)
+      if ( is.infinite(mod1$info[5])  | round( mod1$info[3], 13 ) == 0 ) {
+        p1 <- log(1)
+        t1 <- 0
+      } else {
+        t1 <- ( mod1$be[2, ] / mod1$seb[2, ] )^2
+        p1 <- pf(t1, 1, dof, lower.tail = FALSE, log.p = TRUE)
+      }  ## end if ( is.infinite(mod1$info[5]) ) 
     }  ## end if ( Rfast::sort_unique.length(y) == 2 ) 
     
     if ( Rfast::sort_unique.length(x) == 2 ) {
-      mod2 <- lme4::glmer(x ~ y + (1|id), family = "binomial")
-      mod0 <- lme4::glmer(x ~ 1 + (1|id), family = "binomial")
+      mod2 <- lme4::glmer(x ~ y + (1|group), family = "binomial")
+      mod0 <- lme4::glmer(x ~ 1 + (1|group), family = "binomial")
       t2 <- anova(mod0, mod2)[2, 6]
       p2 <- pchisq(t2, 1, lower.tail = FALSE, log.p = TRUE)
     } else if ( sum(round(x) - x) == 0 ) {
-      mod2 <- lme4::glmer(x ~ y + (1|id), family = "poisson")
-      mod0 <- lme4::glmer(x ~ 1 + (1|id), family = "poisson")
+      mod2 <- lme4::glmer(x ~ y + (1|group), family = "poisson")
+      mod0 <- lme4::glmer(x ~ 1 + (1|group), family = "poisson")
       t2 <- anova(mod0, mod2)[2, 6]
       p2 <- pchisq(t2, 1, lower.tail = FALSE, log.p = TRUE)
     } else {
       dof <- n - 4
-      mod2 <- Rfast::rint.reg(x, y, id)
-      t2 <- ( mod2$be[2, ]/mod2$seb[2, ] )^2
-      p2 <- pf(t2, 1, dof, lower.tail = FALSE, log.p = TRUE)
+      mod2 <- Rfast::rint.reg(x, y, group)
+      if ( is.infinite(mod2$info[5]) | round( mod1$info[3], 13 ) == 0 ) {
+        p2 <- log(1)
+        t2 <- 0
+      } else {
+        t2 <- ( mod2$be[2, ] / mod2$seb[2, ] )^2
+        p2 <- pf(t2, 1, dof, lower.tail = FALSE, log.p = TRUE)
+      }  ## end if ( is.infinite(mod2$info[5]) ) 
     }  ## end if ( Rfast::sort_unique.length(x) == 2 ) 
 
     
   } else {  ### with conditioning set   
     z <- dat[, cs]
     dof <- 1
-    
     if ( Rfast::sort_unique.length(y) == 2 ) {
-      mod1 <- lme4::glmer(y ~ z + x + (1|id), family = "binomial")
-      mod0 <- lme4::glmer(y ~ z + (1|id), family = "binomial")
+      mod1 <- lme4::glmer(y ~ z + x + (1|group), family = "binomial")
+      mod0 <- lme4::glmer(y ~ z + (1|group), family = "binomial")
       t1 <- anova(mod0, mod1)[2, 6]
       p1 <- pchisq(t1, 1, lower.tail = FALSE, log.p = TRUE)
     } else if ( sum(round(y) - y) == 0 ) {
-      mod1 <- lme4::glmer(y ~ z + x + (1|id), family = "poisson")
-      mod0 <- lme4::glmer(y ~ z + (1|id), family = "poisson")
+      mod1 <- lme4::glmer(y ~ z + x + (1|group), family = "poisson")
+      mod0 <- lme4::glmer(y ~ z + (1|group), family = "poisson")
       t1 <- anova(mod0, mod1)[2, 6]
       p1 <- pchisq(t1, 1, lower.tail = FALSE, log.p = TRUE)
     } else {
-      dof <- n - length(mod1$be) - 2
-      mod1 <- Rfast::rint.reg(y, cbind(x, z), id)
+      mod0 <- Rfast::rint.reg(y, x, group)
+      mod1 <- Rfast::rint.reg(y, cbind(x, z), group)
       if ( mod1$info[5] >= mod0$info[5] ) {
         p1 <- log(1)
         t1 <- 0
       } else {
+        dof <- n - length(mod1$be) - 2
         t1 <- ( mod1$be[2, ] / mod1$seb[2, ] )^2
         p1 <- pf(t1, 1, dof, lower.tail = FALSE, log.p = TRUE)
       }  ## end if ( mod1$info[5] >= mod0$info[5] ) 
     }  ## end if ( Rfast::sort_unique.length(y) == 2 )
     
     if ( Rfast::sort_unique.length(x) == 2 ) {
-      mod2 <- lme4::glmer(x ~ z + y + (1|id), family = "binomial")
-      mod0 <- lme4::glmer(x ~ z + (1|id), family = "binomial")
+      mod2 <- lme4::glmer(x ~ z + y + (1|group), family = "binomial")
+      mod0 <- lme4::glmer(x ~ z + (1|group), family = "binomial")
       t2 <- anova(mod0, mod2)[2, 6]
       p2 <- pchisq(t2, 1, lower.tail = FALSE, log.p = TRUE)
     } else if ( sum(round(x) - x) == 0 ) {
-      mod2 <- lme4::glmer(x ~ z + y + (1|id), family = "poisson")
-      mod0 <- lme4::glmer(x ~ z + (1|id), family = "poisson")
+      mod2 <- lme4::glmer(x ~ z + y + (1|group), family = "poisson")
+      mod0 <- lme4::glmer(x ~ z + (1|group), family = "poisson")
       t2 <- anova(mod0, mod2)[2, 6]
       p2 <- pchisq(t2, 1, lower.tail = FALSE, log.p = TRUE)
     } else {  
-      dof <- n - length(mod1$be) - 2
-      mod2 <- Rfast::rint.reg(x, cbind(y, z), id)
+      mod0 <- Rfast::rint.reg(x, y, group)
+      mod2 <- Rfast::rint.reg(x, cbind(y, z), group)
       if ( mod2$info[5] >= mod0$info[5] ) {
         p2 <- log(1)
         t2 <- 0
       } else {
+        dof <- n - length(mod2$be) - 2
         t2 <- ( mod2$be[2, ] / mod2$seb[2, ] )^2
         p2 <- pf(t2, 1, dof, lower.tail = FALSE, log.p = TRUE)
       }  ## end if ( mod2$info[5] >= mod0$info[5] ) 
     }  # end if ( Rfast::sort_unique.length(x) == 2 )
   }   ## end if ( is.null(cs) ) 
+  
   pval <- min( log(2) + min(p1, p2), max(p1, p2) )
   stat <-  max( 2 * max(t1, t2), min(t1, t2) )
   result <- c(stat, pval, dof)
