@@ -1,4 +1,4 @@
-normlog.fsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshold = 0.05, tol = 2, heavy, robust = FALSE, ncores = 1) {
+normlog.fsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshold = 0.05, tol = 2, ncores = 1) {
   
   dm <- dim(dataset) 
   if ( is.null(dm) ) {
@@ -17,35 +17,36 @@ normlog.fsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshol
   pa <- NCOL(iniset)
   da <- 1:pa
   dataset <- cbind(iniset, dataset)
+  dataset <- as.data.frame(dataset)
+  
   runtime <- proc.time()
   
   devi <- dof <- phi <- numeric(p)
   mi <- glm(target ~., data = as.data.frame( iniset ), weights = wei, family = gaussian(link = log), y = FALSE, model = FALSE )
   do <- length( mi$coefficients )
-  ini <- 2 * as.numeric( logLik(mi) ) 
+  ini <- mi$deviance 
   
   if (ncores <= 1) {
     for (i in 1:p) {
       mi <- glm( target ~ . , data = dataset[, c(da, pa + i)], weights = wei, family = gaussian(link = log), y = FALSE, model = FALSE )
-      devi[i] <- 2 * as.numeric( logLik(mi) )
+      devi[i] <- mi$deviance
       dof[i] <- length( mi$coefficients ) 
       phi[i] <- summary(mi)[[ 14 ]]
     }
     
-    stat <- (devi - ini)/phi
+    stat <- (ini - devi)/(dof - do) / phi
     pval <- pf( stat, dof - do, n - dof, lower.tail = FALSE, log.p = TRUE )
     
   } else {
-    #if ( robust == FALSE ) {  ## Non robust
     cl <- makePSOCKcluster(ncores)
     registerDoParallel(cl)
     mod <- foreach( i = 1:p, .combine = rbind) %dopar% {
       ww <- glm( target ~., data = dataset[, c(da, pa + i)], weights = wei, family = gaussian(link = log) )
-      return( c( 2 * as.numeric( logLik(ww) ), length( ww$coefficients ), summary(ww)[[ 14 ]] ) )
+      return( c( ww$deviance, length( ww$coefficients ), summary(ww)[[ 14 ]] ) )
     }
     
     stopCluster(cl)
-    stat <- (mod[, 1] - ini)/mod[, 3]
+    stat <- (ini - mod[, 1])/(mod[, 2] - do) /mod[, 3]
     pval <- pf( stat, mod[, 2] - do, n - mod[, 2], lower.tail = FALSE, log.p = TRUE )
   }
   
@@ -59,7 +60,6 @@ normlog.fsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshol
   if ( mat[sel, 2] < threshold ) {
     info[k, ] <- mat[sel, ]
     mat <- mat[-sel, , drop = FALSE] 
-    #if ( robust == FALSE ) {
     mi <- glm( target ~., data = dataset[, c(da, sela) ], weights = wei, family = gaussian(link = log), y = FALSE, model = FALSE )
     tool[k] <- BIC( mi )
     moda[[ k ]] <- mi
@@ -76,15 +76,14 @@ normlog.fsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshol
     devi <- dof <- phi <- numeric( pn )  
     
     if ( ncores <= 1 ) {
-      #if ( robust == FALSE ) {  ## Non robust
       for ( i in 1:pn ) {
         ww <- glm( target ~., data = dataset[, c(da, sela, pa + mat[i, 1]) ], weights = wei, family = gaussian(link = log), y = FALSE, model = FALSE )
-        devi[i] <- 2 * as.numeric( logLik(ww) )
+        devi[i] <- ww$deviance
         dof[i] <- length( ww$coefficients ) 
         phi[i] <- summary(ww)[[ 14 ]]
       }
-      stat <- (devi - ini)/phi
-      pval <- pf( stat, dof - do, , n - dof, lower.tail = FALSE, log.p = TRUE )
+      stat <- (ini - devi)/(dof - do) / phi
+      pval <- pf( stat, dof - do, n - dof, lower.tail = FALSE, log.p = TRUE )
       
     } else {
       
@@ -92,10 +91,10 @@ normlog.fsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshol
       registerDoParallel(cl)
       mod <- foreach( i = 1:pn, .combine = rbind) %dopar% {
         ww <- glm( target ~., data = dataset[, c(da, sela, pa + mat[i, 1]) ], weights = wei, family = gaussian(link = log) )
-        return( c( 2 * as.numeric( logLik(ww) ), length( ww$coefficients ), summary(ww)[[ 14 ]] ) )
+        return( c( ww$deviance, length( ww$coefficients ), summary(ww)[[ 14 ]] ) )
       }
       stopCluster(cl)
-      stat <- (mod[, 1] - ini)/mod[, 3]
+      stat <- (ini - mod[, 1])/(mod[, 2] - do) / mod[, 3]
       pval <- pf( stat, mod[, 2] - do, n - mod[, 2], lower.tail = FALSE, log.p = TRUE )
     }
     
@@ -120,11 +119,9 @@ normlog.fsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshol
     } else   info <- info
     
   }
-  
   ############
   ###       k greater than 2
   ############ 
-  
   if ( nrow(info) > 1  &  nrow(mat) > 0 ) {
     while ( info[k, 2] < threshold &  k < n - 15  &  tool[ k - 1 ] - tool[ k ] > tol  &  nrow(mat) > 0  )  {
       
@@ -137,12 +134,12 @@ normlog.fsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshol
       if (ncores <= 1) {  
         for ( i in 1:pn ) {
           ma <- glm( target ~., data = dataset[, c(da, sela, pa + mat[i, 1] ) ], weights = wei, family = gaussian(link = log), y = FALSE, model = FALSE )
-          devi[i] <- 2 * as.numeric( logLik(ma) )
+          devi[i] <- ma$deviance
           dof[i] <- length( ma$coefficients ) 
           phi[i] <- summary(ma)[[ 14 ]]
         }
         
-        stat <- (devi - ini)/phi
+        stat <- (ini - devi)/(dof - do) /phi
         pval <- pf( stat, dof - do, n - dof, lower.tail = FALSE, log.p = TRUE )
         
       } else {
@@ -150,11 +147,11 @@ normlog.fsreg_2 <- function(target, dataset, iniset = NULL, wei = NULL, threshol
         registerDoParallel(cl)
         mod <- foreach( i = 1:pn, .combine = rbind) %dopar% {
           ww <- glm( target ~., data = dataset[, c(da, sela, pa + mat[i, 1]) ], weights = wei, family = gaussian(link = log), y = FALSE, model = FALSE )
-          return( c( 2 * as.numeric( logLik(ww) ), length( ww$coefficients ), summary(ww)[[ 14 ]] ) )
+          return( c( ww$deviance, length( ww$coefficients ), summary(ww)[[ 14 ]] ) )
         }
         
         stopCluster(cl)
-        stat <- (mod[, 1] - ini)/mod[, 3]
+        stat <- (ini - mod[, 1])/(mod[, 2] - do)/mod[, 3]
         pval <- pf( stat, mod[, 2] - do, n - mod[, 2], lower.tail = FALSE, log.p = TRUE )
       }
       
