@@ -1,5 +1,5 @@
-permCR = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, univariateModels=NULL, hash = FALSE, stat_hash=NULL, pvalue_hash=NULL,
-                  robust=FALSE, threshold = 0.05, R = 999){
+permCR = function(target, dataset, xIndex, csIndex, wei = NULL, univariateModels=NULL, hash = FALSE, stat_hash=NULL, pvalue_hash=NULL,
+                 threshold = 0.05, R = 999){
   # Conditional independence test based on the Log Likelihood ratio test
   if (!survival::is.Surv(target) )  stop('The survival test can not be performed without a Surv object target');
   csIndex[ which( is.na(csIndex) ) ] = 0;
@@ -13,17 +13,15 @@ permCR = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, u
     if ( is.null(stat_hash[[key]]) == FALSE ) {
       stat = stat_hash[[key]];
       pvalue = pvalue_hash[[key]];
-      flag = 1;
-      
-      results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
   }
   #initialization: these values will be returned whether the test cannot be carried out
-  pvalue = 1;
+  pvalue = log(1)
   stat = 0;
-  flag = 0;
-  results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+  results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   cox_results = NULL;
   cox_results_full = NULL;
   #timeIndex = dim(dataset)[2];
@@ -45,7 +43,7 @@ permCR = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, u
             step <- step + ( anova(bit2)[2, 2] > stat )
             j <- j + 1
           }
-          pvalue <- (step + 1) / (R + 1) 
+          pvalue <- log( (step + 1) / (R + 1) )
 		}  
       } else {
 	      options(warn = -1)
@@ -63,14 +61,12 @@ permCR = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, u
             step <- step + ( anova(bit2)[pr, 2] > stat )
             j <- j + 1
           }
-          pvalue <- (step + 1) / (R + 1) 
+          pvalue <- log( (step + 1) / (R + 1) )
 		}  
       }  
-      flag = 1;
       if ( is.na(pvalue) || is.na(stat) ) {
-        pvalue = 1;
+        pvalue = log(1)
         stat = 0;
-        flag = 0;
       } else {
         #update hash objects
         if( hash )  {
@@ -78,6 +74,6 @@ permCR = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, u
           pvalue_hash[[key]] <- pvalue;     #.set(pvalue_hash , key , pvalue)
         }
       }
-      results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
 }
\ No newline at end of file
