@@ -1,7 +1,7 @@
-permIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NULL, univariateModels = NULL, hash = FALSE, stat_hash = NULL, 
-                       pvalue_hash = NULL,robust = FALSE, threshold = 0.05, R = 999) {
+permIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, univariateModels = NULL, hash = FALSE, stat_hash = NULL, 
+                       pvalue_hash = NULL, threshold = 0.05, R = 999) {
   # TESTINDPOIS Conditional Independence Test for discrete class variables 
-  # PVALUE = TESTINDPOIS(Y, DATA, XINDEX, CSINDEX, DATAINFO)
+  # PVALUE = TESTINDPOIS(Y, DATA, XINDEX, CSINDEX)
   # This test provides a p-value PVALUE for the NULL hypothesis H0 which is
   # X is independent by TARGET given CS. The pvalue is calculated following
   # nested models
@@ -11,13 +11,10 @@ permIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NU
   #   DATASET: a numeric data matrix containing the variables for performing the test. They can be mixed variables. 
   #   XINDEX: the index of the variable whose association with the target we want to test. 
   #   CSINDEX: the indices if the variable to condition on. 
-  #   DATAINFO: information on the structure of the data
-  # this method returns: the pvalue PVALUE, the statistic STAT and a control variable FLAG.
-  # if FLAG == 1 then the test was performed succesfully
+  # this method returns: the pvalue PVALUE, the statistic STAT.
   #if the test cannot performed succesfully these are the returned values
-  pvalue = 1;
+  pvalue = log(1)
   stat = 0;
-  flag = 0;
   csIndex[which(is.na(csIndex))] = 0;
   thres <- threshold * R + 1
   
@@ -29,8 +26,7 @@ permIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NU
     if ( !is.null(stat_hash[[key]]) ) {
       stat = stat_hash[[key]];
       pvalue = pvalue_hash[[key]];
-      flag = 1;
-      results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
   }
@@ -40,14 +36,14 @@ permIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NU
       stat_hash[[key]] <- 0;      #.set(stat_hash , key , 0)
       pvalue_hash[[key]] <- 1;         #.set(pvalue_hash , key , 1)
     }
-    results <- list(pvalue = 1, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   
   #check input validity
   if ( xIndex < 0 || csIndex < 0 ) {
     message(paste("error in testIndPois : wrong input of xIndex or csIndex"))
-    results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   
@@ -56,7 +52,6 @@ permIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NU
   #extract the data
   x = dataset[, xIndex];
   cs = dataset[, csIndex];
-  #if x = any of the cs then pvalue = 1 and flag = 1.
   #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
   if ( length(cs) != 0 ) {
     if ( is.null(dim(cs)[2]) ) {  #cs is a vector
@@ -65,7 +60,7 @@ permIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NU
           stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
           pvalue_hash[[key]] <- 1;#.set(pvalue_hash , key , 1)
         }
-        results <- list(pvalue = 1, stat = 0, flag = 1, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+        results <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
       }
     } else {     #more than one var
@@ -75,7 +70,7 @@ permIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NU
             stat_hash[[key]] <- 0;           #.set(stat_hash , key , 0)
             pvalue_hash[[key]] <- 1;        #.set(pvalue_hash , key , 1)
           }
-          results <- list(pvalue = 1, stat = 0, flag = 1, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+          results <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
         }
       }
@@ -88,7 +83,7 @@ permIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NU
         fit2 = glm(target ~ x, family = inverse.gaussian(log), weights = wei)
         dev2 <- fit2$deviance
         stat = fit2$null.deviance - dev2
-    	if ( stat > 0 ) {
+    	  if ( stat > 0 ) {
           step <- 0
           j <- 1		
           n <- length(target)
@@ -98,15 +93,15 @@ permIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NU
             step <- step + ( bit2$deviance < dev2 )
             j <- j + 1
           }
-          pvalue <- (step + 1) / (R + 1) 
+          pvalue <- log( (step + 1) / (R + 1) )
         } 
       } else {
         fit1 = glm(target ~ cs, family = inverse.gaussian(log), weights = wei)
         fit2 = glm(target ~ cs + x, family = inverse.gaussian(log), weights = wei)
         dev2 <- fit2$deviance
         stat <- fit1$deviance - dev2
-    	if ( stat > 0 ) {
-		  step <- 0
+    	  if ( stat > 0 ) {
+		      step <- 0
           j <- 1		
           n <- length(target)
           while (j <= R & step < thres ) {
@@ -115,15 +110,12 @@ permIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NU
             step <- step + ( bit2$deviance < dev2 )
             j <- j + 1
           }
-          pvalue <- (step + 1) / (R + 1) 
+          pvalue <- log( (step + 1) / (R + 1) )
 		}  
       } 
-      flag = 1;
-      #last error check
       if ( is.na(pvalue) || is.na(stat) ) {
-        pvalue = 1;
+        pvalue = log(1)
         stat = 0;
-        flag = 0;
       } else {
         #update hash objects
         if (hash) {
@@ -132,26 +124,13 @@ permIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NU
         }
       }
 
-      results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     },
     error=function(cond) {
-      #   message(paste("error in try catch of the testIndPois test"))
-      #   message("Here's the original error message:")
-      #   message(cond)
-      #   #        #for debug
-      #   #        print("\nxIndex = \n");
-      #   #        print(xIndex);
-      #   #        print("\ncsindex = \n");
-      #   #        print(csIndex);
-      #   
-      #   stop();
-      #error case
-      pvalue = 1;
-      stat = 0;
-      flag = 0;
-      
-      results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      pvalue = log(1)
+      stat = 0;    
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     },
     finally={}
