@@ -1,7 +1,7 @@
-permNB = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, univariateModels=NULL , hash = FALSE, stat_hash=NULL, 
- pvalue_hash=NULL,robust=FALSE, threshold = 0.05, R = 999) {
+permNB = function(target, dataset, xIndex, csIndex, wei = NULL, univariateModels=NULL , hash = FALSE, stat_hash=NULL, 
+ pvalue_hash=NULL, threshold = 0.05, R = 999) {
   # TESTINDNB Conditional Independence Test for discrete class variables 
-  # PVALUE = TESTINDNB(Y, DATA, XINDEX, CSINDEX, DATAINFO)
+  # PVALUE = TESTINDNB(Y, DATA, XINDEX, CSINDEX,)
   # This test provides a p-value PVALUE for the NULL hypothesis H0 which is
   # X is independent by TARGET given CS. The pvalue is calculated following
   # nested models
@@ -11,13 +11,10 @@ permNB = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, u
   #   DATASET: a numeric data matrix containing the variables for performing the test. They can be mixed variables. 
   #   XINDEX: the index of the variable whose association with the target we want to test. 
   #   CSINDEX: the indices if the variable to condition on. 
-  #   DATAINFO: information on the structure of the data
-  # this method returns: the pvalue PVALUE, the statistic STAT and a control variable FLAG.
-  # if FLAG == 1 then the test was performed succesfully
+  # this method returns: the pvalue PVALUE, the statistic STAT and a control variable.
   #if the test cannot performed succesfully these are the returned values
-  pvalue = 1;
+  pvalue = log(1)
   stat = 0;
-  flag = 0;
   csIndex[which(is.na(csIndex))] = 0;
   thres <- threshold * R + 1
   
@@ -29,8 +26,7 @@ permNB = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, u
     if( !is.null(stat_hash[[key]]) )   {
       stat = stat_hash[[key]];
       pvalue = pvalue_hash[[key]];
-      flag = 1;
-      results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
   }
@@ -41,22 +37,20 @@ permNB = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, u
       stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
       pvalue_hash[[key]] <- 1;#.set(pvalue_hash , key , 1)
     }
-    results <- list(pvalue = 1, stat = 0, flag = 1, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   #check input validity
   if (xIndex < 0 || csIndex < 0)  {
     message(paste("error in testIndNB : wrong input of xIndex or csIndex"))
-    results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   
   xIndex = unique(xIndex);
   csIndex = unique(csIndex);
-  #extract the data
   x = dataset[ , xIndex];
   cs = dataset[ , csIndex, drop = FALSE];
-  #if x = any of the cs then pvalue = 1 and flag = 1.
   #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
   if ( length(cs) != 0 )   {
     if ( is.null(dim(cs)[2]) )  {   #cs is a vector
@@ -65,7 +59,7 @@ permNB = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, u
           stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
           pvalue_hash[[key]] <- 1;#.set(pvalue_hash , key , 1)
         }
-        results <- list(pvalue = 1, stat = 0, flag = 1, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+        results <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
       }
     } else { #more than one var
@@ -75,13 +69,12 @@ permNB = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, u
             stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
             pvalue_hash[[key]] <- 1;#.set(pvalue_hash , key , 1)
           }
-          results <- list(pvalue = 1, stat = 0, flag = 1, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+          results <- list(pvalue = 1, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
         }
       }
     }
   }
-  #if the conditioning set (cs) is empty, we use a simplified formula
   if ( length(cs) == 0 )  {
     #compute the relationship between x,target directly
     fit2 = MASS::glm.nb( target ~ x, weights = wei )
@@ -97,8 +90,8 @@ permNB = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, u
         step <- step + ( bit2$deviance < dev2 )
         j <- j + 1
       }
-      pvalue <- (step + 1) / (R + 1)
-    } else  pvalue <- 1	  
+      pvalue <- log( (step + 1) / (R + 1) )
+    } else  pvalue <- log(1)	  
     
   } else {
     fit1 = MASS::glm.nb( target ~ cs, weights = wei )
@@ -116,15 +109,12 @@ permNB = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, u
         step <- step + ( bit2$deviance < dev2 )
         j <- j + 1
       }
-      pvalue <- (step + 1) / (R + 1) 
-	} else  pvalue <- 1  
+      pvalue <- log( (step + 1) / (R + 1) )
+	} else  pvalue <- log(1)  
   }
-  flag = 1;
-  #last error check
   if ( is.na(pvalue) || is.na(stat) )  {
-    pvalue = 1;
+    pvalue = log(1)
     stat = 0;
-    flag = 0;
   } else {
     #update hash objects
     if ( hash )  {
@@ -132,6 +122,6 @@ permNB = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, u
       pvalue_hash[[key]] <- pvalue;      #.set(pvalue_hash , key , pvalue)
     }
   }
-  results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+  results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   return(results);
 }
\ No newline at end of file
