@@ -1,7 +1,7 @@
-testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic = FALSE, dataInfo = NULL, univariateModels=NULL , hash = FALSE, stat_hash = NULL,
- pvalue_hash = NULL, robust = FALSE) {
+testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic = FALSE, univariateModels=NULL , hash = FALSE, stat_hash = NULL,
+ pvalue_hash = NULL) {
   # TESTINDFISHER Fisher Conditional Independence Test for continous class variables
-  # PVALUE = TESTINDFISHER(Y, DATA, XINDEX, CSINDEX, DATAINFO)
+  # PVALUE = TESTINDFISHER(Y, DATA, XINDEX, CSINDEX)
   # This test provides a p-value PVALUE for the NULL hypothesis H0 which is
   # X is independent by TARGET given CS. The pvalue is calculated following
   # Fisher's method (see reference below)
@@ -11,9 +11,7 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
   #   DATASET: a numeric data matrix containing the variables for performing the test. They can be only be continuous variables. 
   #   XINDEX: the index of the variable whose association with the target we want to test. 
   #   CSINDEX: the indices if the variable to condition on. 
-  #   DATAINFO: information on the structure of the data
-  # this method returns: the pvalue PVALUE, the statistic STAT and a control variable FLAG.
-  # if FLAG == 1 then the test was performed succesfully
+  # this method returns: the pvalue PVALUE, the statistic STAT.
   # References
   # [1] Peter Spirtes, Clark Glymour, and Richard Scheines. Causation,
   # Prediction, and Search. The MIT Press, Cambridge, MA, USA, second
@@ -23,7 +21,6 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
   #if the test cannot performed succesfully these are the returned values
   pvalue = log(1);
   stat = 0;
-  flag = 0;
   
   if ( !is.list(target) ) {
     n = length( target )
@@ -38,8 +35,7 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
       if (is.null(stat_hash[[key]]) == FALSE) {
         stat = stat_hash[[key]];
         pvalue = pvalue_hash[[key]];
-        flag = 1;
-        results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+        results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
       }
     }
@@ -50,23 +46,21 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
         stat_hash[[key]] <- 0;  #.set(stat_hash , key , 0)
         pvalue_hash[[key]] <- log(1);  #.set(pvalue_hash , key , 1)
       }
-      results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
     
     #check input validity
     if(xIndex < 0 || csIndex < 0) {
       message(paste("error in testIndFisher : wrong input of xIndex or csIndex"))
-      results <- list(pvalue = pvalue, stat = 0, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
     
     xIndex = unique(xIndex);
     csIndex = unique(csIndex);
-    #extract the data
     x = dataset[ , xIndex];
     cs = dataset[ , csIndex, drop = FALSE];
-    #if x = any of the cs then pvalue = 1 and flag = 1.
     #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
     if ( length(cs) != 0 ) {
       if ( is.null(dim(cs)[2]) )  {    #cs is a vector
@@ -75,7 +69,7 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
             stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
             pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
           }
-          results <- list(pvalue = log(1), stat = 0, flag = 1, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+          results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
         }
       } else { #more than one var
@@ -85,22 +79,12 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
               stat_hash[[key]] <- 0;    #.set(stat_hash , key , 0)
               pvalue_hash[[key]] <- log(1);    #.set(pvalue_hash , key , 1)
             }
-            results <- list(pvalue = log(1), stat = 0, flag = 1, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+            results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
             return(results);
           }
         }
       }
     }
-    #if x or target is constant then there is no point to perform the test
-    # if ( Rfast::Var(x) == 0 )  {
-    #   if( hash )  {   #update hash objects
-    #     stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
-    #     pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
-    #   }
-    #   results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
-    #   return(results);
-    # }
-    #trycatch for dealing with errors
     res <- tryCatch(
       {
         #if the conditioning set (cs) is empty, we use a simplified formula
@@ -108,42 +92,28 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
           if ( !is.null(univariateModels) ) {
             pvalue = univariateModels$pvalue[[xIndex]];
             stat = univariateModels$stat[[xIndex]];
-            flag = univariateModels$flag[[xIndex]];
-            results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+            results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
             return(results);
           }
           #compute the correlation coefficient between x,target directly
-          if ( robust ) { ## robust correlation
-            b1 = coef( MASS::rlm(target ~ x, maxit = 2000, method = "MM" ) )[2]
-            b2 = coef( MASS::rlm(x ~ target, maxit = 2000, mehtod = "MM" ) )[2]
-            stat = sqrt( abs (b1 * b2) ) 
-          } else  stat <- cor(x, target);
+           stat <- cor(x, target);
         } else {
-          #perform the test with the cs
-          if ( robust ) { ## robust correlation
-            e1 = resid( MASS::rlm( target ~., data = data.frame( dataset[, csIndex] ), maxit = 2000, method = "MM" ) ) 
-            e2 = resid( MASS::rlm( dataset[, xIndex] ~.,  data = data.frame( dataset[, csIndex] ), maxit = 2000, method = "MM" ) )
-            stat = cor(e1,e2) 
-          }else{
-            tmpm = cbind(x, target, cs);
-            corrMatrix = cor(tmpm);         
-            xyIdx = 1:2;
-            csIdx = 3:(ncol(as.matrix(cs))+2); #or csIdx = 3;          
-            residCorrMatrix = corrMatrix[xyIdx, xyIdx] - as.matrix(corrMatrix[xyIdx, csIdx]) %*% ( solve( as.matrix(corrMatrix[csIdx, csIdx]) , rbind( corrMatrix[csIdx, xyIdx]) ) );
-            stat = residCorrMatrix[1, 2] / sqrt(residCorrMatrix[1, 1] * residCorrMatrix[2, 2]);
-          }
+          tmpm = cbind(x, target, cs);
+          corrMatrix = cor(tmpm);         
+          xyIdx = 1:2;
+          csIdx = 3:(ncol(as.matrix(cs))+2); #or csIdx = 3;          
+          residCorrMatrix = corrMatrix[xyIdx, xyIdx] - as.matrix(corrMatrix[xyIdx, csIdx]) %*% ( solve( as.matrix(corrMatrix[csIdx, csIdx]) , rbind( corrMatrix[csIdx, xyIdx]) ) );
+          stat = residCorrMatrix[1, 2] / sqrt(residCorrMatrix[1, 1] * residCorrMatrix[2, 2]);
         }
         #lets calculate the p-value
         z = 0.5*log( (1+stat)/(1-stat) );
         dof = n - ncol( as.matrix(cs) ) - 3; #degrees of freedom
         stat = sqrt(dof) * abs(z);
         pvalue = log(2) + pt(stat, dof, lower.tail = FALSE, log.p = TRUE) ;  # ?dt for documentation
-        flag = 1;
         #last error check
         if ( is.na(pvalue) || is.na(stat) ) {
           pvalue = log(1);
           stat = 0;
-          flag = 1;
         } else {
           #update hash objects
           if( hash ) {
@@ -152,24 +122,14 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
           }
         }
         #testerrorcaseintrycatch(4);
-        results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+        results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
       },
       error=function(cond) {
-        #    message(paste("warning in try catch of the testIndFisher test"))
-        #    message("Here's the original message:")
-        #    message(cond)
-        #    for debug
-        #    print("\nxIndex = \n");
-        #    print(xIndex);
-        #    print("\ncsindex = \n");
-        #    print(csIndex);
-        #   stop();
         #error case (we are pretty sure that the only error case is when x,cs are highly correlated and the inversion of the matrix is not possible)
         pvalue = log(1);
         stat = 0;
-        flag = 1;
-        results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+        results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
       },
       finally={}
@@ -201,8 +161,7 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
     if(is.null(stat_hash[[key]]) == FALSE) {
       stat = stat_hash[[key]];
       pvalue = pvalue_hash[[key]];
-      flag = 1;
-      aa[[ i ]] <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      aa[[ i ]] <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     }
   }
   #if the xIndex is contained in csIndex, x does not bring any new
@@ -212,31 +171,18 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
       stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
       pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
     }
-    aa[[ i ]] <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    aa[[ i ]] <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   }
   #check input validity
   if(xIndex < 0 || csIndex < 0) {
     message(paste("error in testIndFisher : wrong input of xIndex or csIndex"))
-    aa[[ i ]] <- list(pvalue = pvalue, z = 0, stat = 0, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    aa[[ i ]] <- list(pvalue = pvalue, z = 0, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   }
   
   xIndex = unique(xIndex);
   csIndex = unique(csIndex);
   x = data[ , xIndex];
   cs = data[ , csIndex];
-  #remove equal columns of the CS (takes a lot of time)
-#   if(length(csIndex) > 1)
-#   {
-#     #remove same columns
-#     #cs = unique(as.matrix(cs), MARGIN = 2);
-#     #or
-#     w = which(duplicated(cs, MARGIN = 2))
-#     if(length(w) > 0)
-#     {
-#       cs = cs[,-w]
-#     }
-#   }
-  #if x = any of the cs then pvalue = 1 and flag = 1.
   #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
   if ( length(cs) != 0 )  {
     if ( is.null( dim(cs )[2]) ) {    #cs is a vector
@@ -245,7 +191,7 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
           stat_hash[[key]] <- 0;   #.set(stat_hash , key , 0)
           pvalue_hash[[key]] <- log(1);   #.set(pvalue_hash , key , 1)
         }
-        aa[[ i ]] <- list(pvalue = log(1), z = 0, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+        aa[[ i ]] <- list(pvalue = log(1), z = 0, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       }
     } else {   #more than one var
       for ( col in 1:ncol(cs) ) {
@@ -254,7 +200,7 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
             stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
             pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
           }
-          aa[[ i ]] <- list(pvalue = log(1), z = 0, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+          aa[[ i ]] <- list(pvalue = log(1), z = 0, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         }
       }
     }
@@ -265,7 +211,7 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
       stat_hash[[key]] <- 0;       #.set(stat_hash , key , 0)
       pvalue_hash[[key]] <- log(1);     #.set(pvalue_hash , key , 1)
     }
-    aa[[ i ]] <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    aa[[ i ]] <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   }
   #remove constant columns of cs
   cs = as.matrix(cs)
@@ -278,43 +224,30 @@ aa[[ i ]] <- tryCatch(
     if ( !is.null(univariateModels) )  {
       pvalue = univariateModels$pvalue[[xIndex]];
       stat = univariateModels$stat[[xIndex]];
-      flag = univariateModels$flag[[xIndex]];
-      results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
     #compute the correlation coefficient between x, target directly
-    if ( robust ) { ## robust correlation
-      b1 = coef( MASS::rlm(targ ~ x, maxit = 2000 ) )[2]
-      b2 = coef( MASS::rlm(x ~ targ, maxit = 2000 ) )[2]
-      stat = sqrt( abs (b1 * b2) ) 
-    } else  stat = cor(x, targ);
+     stat = cor(x, targ);
     
   } else{
      #perform the test with the cs
-    if ( robust ) { ## robust correlation
-      e1 = resid( MASS::rlm( targ ~., data = data.frame( data[, csIndex] ), maxit = 2000 ) ) 
-      e2 = resid( MASS::rlm( data[, xIndex] ~.,  data = data.frame( data[, csIndex] ), maxit = 2000 ) )
-      stat = cor(e1,e2) 
-    } else {
-      tmpm = cbind(x, targ, cs);   
-      corrMatrix = cor(tmpm);
-      xyIdx = 1:2;
-      csIdx = 3:(NCOL(cs) + 2); #or csIdx = 3;
-      residCorrMatrix = (corrMatrix[xyIdx, xyIdx]) - as.matrix(corrMatrix[xyIdx, csIdx])%*%(solve( as.matrix(corrMatrix[csIdx, csIdx]) , rbind(corrMatrix[csIdx, xyIdx])) );
-      stat = abs(residCorrMatrix[1,2] / sqrt(residCorrMatrix[1,1] * residCorrMatrix[2,2]));
-    }
+     tmpm = cbind(x, targ, cs);   
+     corrMatrix = cor(tmpm);
+     xyIdx = 1:2;
+     csIdx = 3:(NCOL(cs) + 2); #or csIdx = 3;
+     residCorrMatrix = (corrMatrix[xyIdx, xyIdx]) - as.matrix(corrMatrix[xyIdx, csIdx])%*%(solve( as.matrix(corrMatrix[csIdx, csIdx]) , rbind(corrMatrix[csIdx, xyIdx])) );
+     stat = abs(residCorrMatrix[1,2] / sqrt(residCorrMatrix[1,1] * residCorrMatrix[2,2]));
   }
   #lets calculate the p-value
   z = 0.5 * log( (1 + stat) / (1 - stat) );
   dof = n - NCOL(cs) - 3; #degrees of freedom
   stat = sqrt(dof) * abs(z) ; ## standard errot for Spearman
   pvalue = log(2) + pt(-stat, dof, log.p = TRUE) ;  # ?dt for documentation
-  flag = 1;
   #last error check
   if ( is.na(pvalue) || is.na(stat) ) {
     pvalue = log(1);
     stat = 0;
-    flag = 1;
   } else {
     #update hash objects
     if ( hash ) {
@@ -323,24 +256,14 @@ aa[[ i ]] <- tryCatch(
     }
   }
   #testerrorcaseintrycatch(4);
-   list(pvalue = pvalue, z = z, nu = n, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+   list(pvalue = pvalue, z = z, nu = n, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
 },
 
 error=function(cond) {
-#    message(paste("warning in try catch of the testIndFisher test"))
-#    message("Here's the original message:")
-#    message(cond)
-#      #for debug
-#       print("\nxIndex = \n");
-#       print(xIndex);
-#       print("\ncsindex = \n");
-#       print(csIndex);
-#   stop();
   #error case (we are pretty sure that the only error case is when x,cs are highly correlated and the inversion of the matrix is not possible)
   pvalue = log(1);
   stat = 0;
-  flag = 1;
-  list(pvalue = pvalue, z = z, nu = n, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+  list(pvalue = pvalue, z = z, nu = n, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
  },
 finally={}
 ) 
@@ -371,7 +294,7 @@ finally={}
     pvalue_hash[[key]] <- pvalue  
   }
 
- res = list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+ res = list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
 }
   
  return(res)
