@@ -86,14 +86,14 @@ testIndGEEGamma = function(target, reps = NULL, group, dataset, xIndex, csIndex,
     if ( is.null(reps) ) {
       fit2 <- try( geepack::geeglm( target ~ dataset[, xIndex], family = Gamma(log), id = group, weights = wei, corstr = correl, std.err = se ), silent = TRUE)
     } else {
-      fit2 <- try( geepack::geeglm( target ~ reps + dataset[, xIndex], family = Gamma(log), id = group, weights = wei, corstr = correl, std.err = se ), silent = TRUE) 
+      fit2 <- try( geepack::geeglm( target ~ reps + dataset[, xIndex], family = Gamma(log), id = group, waves = reps, weights = wei, corstr = correl, std.err = se ), silent = TRUE) 
     }
     
   } else {
     if ( is.null(reps) ) {
       fit2 <- try( geepack::geeglm( target ~ dataset[, csIndex] + dataset[, xIndex], family = Gamma(log), id = group, weights = wei, corstr = correl, std.err = se ), silent = TRUE)
     } else {
-      fit2 <- try( geepack::geeglm( target ~ reps + dataset[, csIndex] + dataset[, xIndex], family = Gamma(log), id = group, weights = wei, corstr = correl, std.err = se ), silent = TRUE) 
+      fit2 <- try( geepack::geeglm( target ~ reps + dataset[, csIndex] + dataset[, xIndex], family = Gamma(log), id = group, waves = reps, weights = wei, corstr = correl, std.err = se ), silent = TRUE) 
     }  
   }
   #calculate the p value and stat.
