@@ -1,7 +1,7 @@
-testIndSpearman = function(target, dataset, xIndex, csIndex, wei = NULL, statistic = FALSE, dataInfo = NULL, univariateModels=NULL , hash = FALSE, stat_hash = NULL,
- pvalue_hash = NULL, robust = FALSE)  {
+testIndSpearman = function(target, dataset, xIndex, csIndex, wei = NULL, statistic = FALSE, univariateModels=NULL , hash = FALSE, stat_hash = NULL,
+ pvalue_hash = NULL)  {
   # TESTINDFISHER Fisher Conditional Independence Test for continous class variables
-  # PVALUE = TESTINDFISHER(Y, DATA, XINDEX, CSINDEX, DATAINFO)
+  # PVALUE = TESTINDFISHER(Y, DATA, XINDEX, CSINDEX)
   # This test provides a p-value PVALUE for the NULL hypothesis H0 which is
   # X is independent by TARGET given CS. The pvalue is calculated following
   # Fisher's method (see reference below)
@@ -11,19 +11,12 @@ testIndSpearman = function(target, dataset, xIndex, csIndex, wei = NULL, statist
   #   DATASET: a numeric data matrix containing the variables for performing the test. They can be only be continuous variables. 
   #   XINDEX: the index of the variable whose association with the target we want to test. 
   #   CSINDEX: the indices if the variable to condition on. 
-  #   DATAINFO: information on the structure of the data
-  # this method returns: the pvalue PVALUE, the statistic STAT and a control variable FLAG.
-  # if FLAG == 1 then the test was performed succesfully
-  # References
-  # [1] Peter Spirtes, Clark Glymour, and Richard Scheines. Causation,
-  # Prediction, and Search. The MIT Press, Cambridge, MA, USA, second
-  # edition, January 2001.
+  # this method returns: the pvalue PVALUE, the statistic STAT.
   # Copyright 2012 Vincenzo Lagani and Ioannis Tsamardinos
   # R Implementation by Giorgos Athineou (10/2013)
-  #if the test cannot performed succesfully these are the returned values
+  # if the test cannot performed succesfully these are the returned values
   pvalue = log(1);
   stat = 0;
-  flag = 0;
   
   if ( !is.list(target) ) {
   csIndex[which(is.na(csIndex))] = 0;
@@ -36,8 +29,7 @@ testIndSpearman = function(target, dataset, xIndex, csIndex, wei = NULL, statist
     if(is.null(stat_hash[[key]]) == FALSE)  {
       stat = stat_hash[[key]];
       pvalue = pvalue_hash[[key]];
-      flag = 1;
-      results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
   }
@@ -48,23 +40,22 @@ testIndSpearman = function(target, dataset, xIndex, csIndex, wei = NULL, statist
       stat_hash[[key]] <- 0;   #.set(stat_hash , key , 0)
       pvalue_hash[[key]] <- log(1);   #.set(pvalue_hash , key , 1)
     }
-    results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   
   #check input validity
   if(xIndex < 0 || csIndex < 0)  {
     message(paste("error in testIndFisher : wrong input of xIndex or csIndex"))
-    results <- list(pvalue = pvalue, stat = 0, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = pvalue, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   
-  xIndex = unique(xIndex);
-  csIndex = unique(csIndex);
-  #extract the data
-  x = dataset[ , xIndex];
-  cs = dataset[ , csIndex, drop = FALSE];
-  #if x = any of the cs then pvalue = 1 and flag = 1.
+  xIndex <- unique(xIndex);
+  csIndex <- unique(csIndex);
+  x <- dataset[ , xIndex];
+  cs <- dataset[ , csIndex, drop = FALSE];
+  n <- length(target)
   #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
   if ( length(cs) != 0 )  {
     if ( is.null(dim(cs)[2]) )  {   #cs is a vector
@@ -73,17 +64,17 @@ testIndSpearman = function(target, dataset, xIndex, csIndex, wei = NULL, statist
           stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
           pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
         }
-        results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+        results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
       }
     } else { #more than one var
       for (col in 1:dim(cs)[2]) {
         if ( identical(x, cs[,col]) )  {    #if(!any(x == cs) == FALSE)
           if ( hash )  {   #update hash objects
-            stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
-            pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
+            stat_hash[[key]] <- 0;    #.set(stat_hash , key , 0)
+            pvalue_hash[[key]] <- log(1);     #.set(pvalue_hash , key , 1)
           }
-          results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+          results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
         }
       }
@@ -97,8 +88,7 @@ res <- tryCatch(
     if ( !is.null(univariateModels) )   {
       pvalue = univariateModels$pvalue[[xIndex]];
       stat = univariateModels$stat[[xIndex]];
-      flag = univariateModels$flag[[xIndex]];
-      results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
     #compute the correlation coefficient between x,target directly
@@ -114,47 +104,34 @@ res <- tryCatch(
      stat = abs(residCorrMatrix[1,2] / sqrt(residCorrMatrix[1,1] * residCorrMatrix[2,2]));
   }
   #lets calculate the p-value
-  #comparing against the Student's t distribution
   z = 0.5 * log( (1 + stat) / (1 - stat) );
   dof = n - NCOL(cs) - 3; #degrees of freedom
   w = sqrt(dof) * z / 1.029563;
   pvalue = log(2) + pt(-abs(w), dof, log.p = TRUE) ;  # ?dt for documentation
-  flag = 1;
   #last error check
   if ( is.na(pvalue) || is.na(stat) )  {
     pvalue = log(1);
     stat = 0;
-    flag = 1;
   } else {
     #update hash objects
     if( hash )  {
-      stat_hash[[key]] <- stat;#.set(stat_hash , key , stat)
-      pvalue_hash[[key]] <- pvalue;#.set(pvalue_hash , key , pvalue)
+      stat_hash[[key]] <- stat;       #.set(stat_hash , key , stat)
+      pvalue_hash[[key]] <- pvalue;     #.set(pvalue_hash , key , pvalue)
     }
   }
   #testerrorcaseintrycatch(4);
-  results <- list(pvalue = pvalue, stat = abs(w), flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+  results <- list(pvalue = pvalue, stat = abs(w), stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   return(results);
 },
 error=function(cond) {
-#    message(paste("warning in try catch of the testIndFisher test"))
-#    message("Here's the original message:")
-#    message(cond)
-#    for debug
-#    print("\nxIndex = \n");
-#    print(xIndex);
-#    print("\ncsindex = \n");
-#    print(csIndex);
-#   stop();
   #error case (we are pretty sure that the only error case is when x,cs are highly correlated and the inversion of the matrix is not possible)
   pvalue = log(1);
   stat = 0;
-  flag = 1;
-  results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+  results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   return(results);
 },
 finally={}
-  )    
+)    
 
   
 ##################################  
@@ -187,43 +164,26 @@ finally={}
     if(is.null(stat_hash[[key]]) == FALSE)  {
       stat = stat_hash[[key]];
       pvalue = pvalue_hash[[key]];
-      flag = 1;
-      aa[[ i ]] <- list(pvalue = pvalue, z = z, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      aa[[ i ]] <- list(pvalue = pvalue, z = z, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     }
   }
-  #if the xIndex is contained in csIndex, x does not bring any new
-  #information with respect to cs
   if ( !is.na( match(xIndex, csIndex) ) ) {
     if ( hash )  {      #update hash objects
       stat_hash[[key]] <- 0;      #.set(stat_hash , key , 0)
       pvalue_hash[[key]] <- log(1);         #.set(pvalue_hash , key , 1)
     }
-    aa[[ i ]] <- list(pvalue = log(1), z = 0, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    aa[[ i ]] <- list(pvalue = log(1), z = 0, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   }
   #check input validity
   if(xIndex < 0 || csIndex < 0)  {
     message(paste("error in testIndFisher : wrong input of xIndex or csIndex"))
-    aa[[ i ]] <- list(pvalue = pvalue, z = 0, stat = 0, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    aa[[ i ]] <- list(pvalue = pvalue, z = 0, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   }
   
   xIndex = unique(xIndex);
   csIndex = unique(csIndex);
-  #extract the data
   x = data[ , xIndex];
   cs = data[ , csIndex, drop = FALSE];
-  #remove equal columns of the CS (takes a lot of time)
-#   if(length(csIndex) > 1)
-#   {
-#     #remove same columns
-#     #cs = unique(as.matrix(cs), MARGIN = 2);
-#     #or
-#     w = which(duplicated(cs, MARGIN = 2))
-#     if(length(w) > 0)
-#     {
-#       cs = cs[,-w]
-#     }
-#   }
-  #if x = any of the cs then pvalue = 1 and flag = 1.
   #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
   if ( length(cs) != 0 )   {
     if ( is.null( dim(cs )[2]) )  {     #cs is a vector
@@ -232,7 +192,7 @@ finally={}
           stat_hash[[key]] <- 0;          #.set(stat_hash , key , 0)
           pvalue_hash[[key]] <- log(1);       #.set(pvalue_hash , key , 1)
         }
-        aa[[ i ]] <- list(pvalue = log(1), z = 0, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+        aa[[ i ]] <- list(pvalue = log(1), z = 0, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       }
     } else {         #more than one var
       for ( col in 1:ncol(cs) ) {
@@ -241,7 +201,7 @@ finally={}
             stat_hash[[key]] <- 0;            #.set(stat_hash , key , 0)
             pvalue_hash[[key]] <- log(1);           #.set(pvalue_hash , key , 1)
           }
-          aa[[ i ]] <- list(pvalue = log(1), z = 0, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+          aa[[ i ]] <- list(pvalue = log(1), z = 0, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         }
       }
     }
@@ -252,7 +212,7 @@ finally={}
       stat_hash[[key]] <- 0;           #.set(stat_hash , key , 0)
       pvalue_hash[[key]] <- log(1);       #.set(pvalue_hash , key , 1)
     }
-    aa[[ i ]] <- list(pvalue = log(1), z = 0, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    aa[[ i ]] <- list(pvalue = log(1), z = 0, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   }
   #remove constant columns of cs
   cs = cs[, apply(cs, 2, var, na.rm=TRUE) != 0 ]
@@ -264,8 +224,7 @@ aa[[ i ]] <- tryCatch(
     if ( !is.null(univariateModels) )  {
       pvalue = univariateModels$pvalue[[xIndex]];
       stat = univariateModels$stat[[xIndex]];
-      flag = univariateModels$flag[[xIndex]];
-      results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
     #compute the correlation coefficient between x, target directly
@@ -280,18 +239,15 @@ aa[[ i ]] <- tryCatch(
       residCorrMatrix = (corrMatrix[xyIdx, xyIdx]) - as.matrix(corrMatrix[xyIdx, csIdx])%*%(solve( as.matrix(corrMatrix[csIdx, csIdx]) , rbind(corrMatrix[csIdx, xyIdx])) );
       stat = abs(residCorrMatrix[1,2] / sqrt(residCorrMatrix[1,1] * residCorrMatrix[2,2]));
   }
-
   #comparing against the Student's t distribution
   z = 0.5 * log( (1 + stat) / (1 - stat) );
-  dof = n - ncol(as.matrix(cs)) - 3; #degrees of freedom
+  dof = n - dim(cs)[2] - 3; #degrees of freedom
   w = sqrt(dof) * abs(z) / 1.029563; ## standard errot for Spearman
   pvalue = log(2) + pt(-w, dof, log.p = TRUE) ;  # ?dt for documentation
-  flag = 1;
   #last error check
   if ( is.na(pvalue) || is.na(stat) ) {
     pvalue = log(1);
     stat = 0;
-    flag = 1;
   } else {
     #update hash objects
     if( hash ) {
@@ -300,23 +256,13 @@ aa[[ i ]] <- tryCatch(
     }
   }
   #testerrorcaseintrycatch(4);
-  list(pvalue = pvalue, z = z, nu = n, stat = w, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+  list(pvalue = pvalue, z = z, nu = n, stat = w, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
 },
 error=function(cond) {
-#    message(paste("warning in try catch of the testIndFisher test"))
-#    message("Here's the original message:")
-#    message(cond)
-#    for debug
-#    print("\nxIndex = \n");
-#    print(xIndex);
-#    print("\ncsindex = \n");
-#    print(csIndex);
-#   stop();
   #error case (we are pretty sure that the only error case is when x,cs are highly correlated and the inversion of the matrix is not possible)
   pvalue = log(1);
   stat = 0;
-  flag = 1;
-  list(pvalue = pvalue, z = z, nu = n, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+  list(pvalue = pvalue, z = z, nu = n, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
  },
 finally={}
 ) 
@@ -347,7 +293,7 @@ finally={}
     pvalue_hash[[key]] <- pvalue  
   }
 
- res = list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+ res = list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
 }
   
  res
